define(
//begin v1.x content
({
	"saveLabel": "儲存",
	"saveSettingLabelOn": "設定自動儲存間隔...",
	"saveSettingLabelOff": "關閉自動儲存",
	"saveSettingdialogTitle": "自動儲存",
	"saveSettingdialogDescription": "指定自動儲存間隔",
	"saveSettingdialogParamName": "自動儲存間隔",
	"saveSettingdialogParamLabel": "分鐘",
	"saveSettingdialogButtonOk": "設定間隔",
	"saveSettingdialogButtonCancel": "取消",
	"saveMessageSuccess": "已儲存於 ${0}",
	"saveMessageFail": "無法儲存於 ${0}"
})
//end v1.x content
);
